<?php
// cpmslideshow.php  Script which displays images etc returned by cpmfetch in a slide show  
// The configuration of these is defined in a file which is read in, for example 
// cpmfetch/inc/cpmslideshowsetupxxx.inc.php  where xxx is any number of characters
// cpmfetch release 2.2   Newly introduced by KF (406man)

function cpmslideshow ($stpfilename="") {
    global $cpmfetchdir;
    $cpmfetchphp = "cpmfetch.php";      // The main program file used
    $untitled = "Untitled";         // Text to display when image title is wanted but there is no text
    $defaultsize = "large";    // Default image size for resizing if not supplied
    $defaultlink = "int";    // Default destination for the image link is the image display screen 
    $htmlbreak = "<br>";
    $imagesFound = false;
    $noImageMsg = "No images found. Unable to run slideshow";

    if (!isset ($options)) $options = array();      // Create an empty options array in case the config file being pulled in doesn't have one
    if ($stpfilename == "") {
        exit("cpmslideshow.php - no setup file passed in");
    } else {
        $cpmfetchmainfile = $cpmfetchdir . $cpmfetchphp;
        require($cpmfetchmainfile);                    // Pull in the main file cpmfetch.php
        $objCpm = new cpm();
        $objCpm->cpm_setReturnType("resultset");
        require ($stpfilename);                     // Pull in the setup file which runs the fetch
    }
    if (empty($data)) {                             // Check whether no images were found
        echo $noImageMsg . $htmlbreak;
    } else {
        $imagesFound = true;
        $objCpm->loadOptions($options);  // Fill in the OptionHash and styleHash arrays ready for the Tag calls to use them
        if (array_key_exists('imageheight', $options)) $objCpm->insertOptionAttributes('imageattributes','height',$options['imageheight']);
        if (array_key_exists('imagewidth', $options)) $objCpm->insertOptionAttributes('imageattributes','width',$options['imagewidth']);
        $imgstyletag   = ((array_key_exists('imagestyle', $options)) ? $objCpm->styleHash['imagestyle'] : "") . 
                         ((array_key_exists('imagestyleproperties', $options)) ? $objCpm->styleHash['imagestyleproperties'] : "");
        $imgattributes =  (array_key_exists('imagewidth', $options)) ? $objCpm->getOptionAttributes("imageattributes") : "";
        $imgtags = $imgstyletag . " " . $imgattributes;

        $cellstyleproperties = (array_key_exists('cellstyleproperties', $options))  ? $objCpm->styleHash['cellstyleproperties'] : "";
        $cellstyletag = (array_key_exists('cellstyle', $options)) ? $objCpm->styleHash['cellstyle'] : "";
        $cellattributes  = (array_key_exists('cellattributes', $options)) ? $objCpm->getOptionAttributes('cellattributes') : "";
        $celltag = $cellstyleproperties . " " . $cellattributes . " " . $cellstyletag;

        $tablestyleproperties = (array_key_exists('tablestyleproperties', $options))  ? $objCpm->styleHash['tablestyleproperties'] : "";
        $tablestyletag = (array_key_exists('tablestyle', $options))  ? $objCpm->styleHash['tablestyle'] : "";
        $tableattributes = (array_key_exists('tableattributes', $options))  ? $objCpm->getOptionAttributes("tableattributes") : "";
        $tabletag =  $tablestyleproperties . " " . $tableattributes . " " . $tablestyletag;  

        $a_tag_id = 'id="slidelink"';  // Default id value for the <a> tag
        if (array_key_exists('linkstyle', $options))       $a_tag_id .= " {$objCpm->styleHash['linkstyle']}";  
        $a_attributes = $a_tag_id;
         
        // Check $options has default value for various keys as they can be set (or not) in the config file
        if (!array_key_exists('imagesize', $options)) $options['imagesize'] = $defaultsize;  
        if (!array_key_exists('imagelink', $options)) $options['imagelink'] = $defaultlink;  
        $cpmloadingpngurl = $objCpm->cfg['cpg_url'] . 'cpmfetch/loading.png';
        $cpmdisppicjsurl = $objCpm->cfg['cpg_url'] . 'cpmfetch/js/cpmfetchdisp.js';
        $cpmfitpicjsurl  = $objCpm->cfg['cpg_url'] . 'cpmfetch/js/cpmfitpic.js';
        $firsttime = true;
        $image_prefix = $objCpm->getPrefixToUse($options);
        foreach ($data as $row) {
            // Prepare to write out the image information from PHP into js variables
            $imagename = $objCpm->cfg['cpg_url'] . $objCpm->getImageToUse($row['pFilepath'], $row['pFilename'] , $image_prefix);
            if (array_key_exists('linktemplate',$objCpm->optionHash)) {     // Has the link been overriden ? If not, standard link
        		$imagelink =  $objCpm->createDescription($objCpm->optionHash['linktemplate'],$row);
            } else {
                $imagelink = $objCpm->createlink($row['pFilepath'], rawurlencode($row['pFilename']), $row['pAid'], $row['pPid'], $options['imagelink']);
            }
            $a_tag = $objCpm->htmlTagAHREF($imagelink, "", $a_attributes);
            $alttag    = (array_key_exists('cpmAlttag', $row)) ? $objCpm->createDescription($options['alttag'],$row) : "";
            $showtitle = array_key_exists('subtitle', $options);
            if ($showtitle) {
                $subtitletext  = $objCpm->createDescription($options['subtitle'],$row);
                $titleid = array_key_exists('subtitlestyle', $options) ? $objCpm->styleHash['subtitlestyle'] : "";
                $titlestyle = array_key_exists('subtitlestyleproperties', $options) ? $objCpm->styleHash['subtitlestyleproperties'] : "";
                $titleline = "<p id=\"Titlefield\" {$titlestyle} {$titleid}></p>";
            } else {
                $subtitletext = "";
                $titleline = "";
            }
            if (array_key_exists('subtitlelink', $options)){
                $otherattributes = "id=\"Titlefield\" {$titlestyle} {$titleid}";
                $titleline = $objCpm->htmlTagAHREF($imagelink, $objCpm->createDescription($objCpm->optionHash['subtitle'],$row), $otherattributes);
            }    
            $thelink = $imagelink;
            if (array_key_exists('windowtarget',$objCpm->optionHash)) {  //For the windowtarget option build the link
                if (array_key_exists('imagelink',$objCpm->optionHash)) {
                    switch ($options['imagelink']) {
                        case 'large' :
                            // Any single quotes in the URL will cause it to fail so filter them out and encode in base64. This only affects the appearance of theTitle field in the newly created image display window 
                            $a_tag = $objCpm->createDescription($a_tag,$row);
                            switch ($options['windowtarget']) {
                                case "_blank-js":
                                case "_blank-cfshow":
    //                                $strippedtitle = str_replace("&#039;", "'", $subtitletext);  // Replace any coded ' from the title string 
                                    $strippedtitle = str_replace("&#039;", "'", $subtitletext);  // Replace any coded ' from the title string 
                                    $encodedtitle = base64_encode($strippedtitle);
    //                                $thelink = "javascript:cpmshowpic('" . $imagelink . "','" . $encodedtitle . "')";
                                    $thelink = "javascript:cpmshowpic('" . $imagelink . "','" . $encodedtitle . "')";
                                       break;
                                case "_blank":
                                    break;
                                default:
                            } 
                            break;
                        case 'album':
                        case 'int':
                        case 'thumb':
                            break;
                    }    
                }
            }

            $a_tag = str_replace('</a>', '', $a_tag);   // Delete the trailing </a> tag. A bit of a bodge but the easiest way to re-use the htmlTagAHREF function        
            // Replace any single quotes by their character code otherwise this printing method of populating js variables gets in a mess when delimiting quoted strings
            $thelink = str_replace("'", "&#039;", $thelink);
            if ($firsttime) {       // Go into script mode on the first time through 
                echo "<script>";
                $firsttime = false;
            }
            print "Pic[a]='"  . $imagename . "'\n";
            print "Lnk[a]='"  . $thelink . "'\n";
            print "Ttl[a]='"  . $subtitletext . "'\n";
            print "alt[a++]='" . $alttag . "'\n";
        }
        $showlink = ($thelink == '') ? false : true;  // Only need to do this once. Do it on the final image.
        // Effectively - convert the php variables into js variables being careful to get the data type correct
        print "showlink  =" . ($showlink  ? "true" : "false") . "\n";
        print "showtitle =" . ($showtitle ? "true" : "false") . "\n";
        print "slideShowTimer =" . $slideShowTimer . "\n";
        print "</script>" . "\n";

    // Below are four different HTML templates for the different combinations of link and title to be shown
    // 1. Link and title
    $cpmtemplate_link_title = <<<EOT
        <html>
        <script type="text/javascript" src="{$cpmdisppicjsurl}"></script>
        <script type="text/javascript" src="{$cpmfitpicjsurl}"></script>
        <table id="slidetable" {$tabletag}>
            <tr>
            <td {$celltag}>
                {$a_tag}
                <img onload="cpmRunSlideInit()" src="{$cpmloadingpngurl}" {$imgtags} name="SlideShow">
                </a>
                {$titleline}
            </td>
            </tr>
        </table>
        </html>
    EOT;

    // 2. No link, Title 
    $cpmtemplate_nolink_title = <<<EOT
        <html>
        <script type="text/javascript" src="{$cpmdisppicjsurl}"></script>
        <script type="text/javascript" src="{$cpmfitpicjsurl}"></script>
        <table id="slidetable" {$tabletag}>
            <tr>
            <td {$celltag}>
                <img onload="cpmRunSlideInit()" src="{$cpmloadingpngurl}" {$imgtags} name="SlideShow">
                {$titleline}
            </td>
            </tr>
        </table>
        </html>
    EOT;

    // 3. link, no title
    $cpmtemplate_link_notitle = <<<EOT
        <html>
        <script type="text/javascript" src="{$cpmdisppicjsurl}"></script>
        <script type="text/javascript" src="{$cpmfitpicjsurl}"></script>
        <table id="slidetable" {$tabletag}>
            <tr>
            <td {$celltag}>
                {$a_tag}
                    <img onload="cpmRunSlideInit()" src="{$cpmloadingpngurl}" {$imgtags} name="SlideShow">
                </a>
            </td>
            </tr>
        </table>
        </html>
    EOT;

    // 4. No link, no title
    $cpmtemplate_nolink_notitle = <<<EOT
        <html>
        <script type="text/javascript" src="{$cpmdisppicjsurl}"></script>
        <script type="text/javascript" src="{$cpmfitpicjsurl}"></script>
        <table id="slidetable" {$tabletag}>
            <tr>
            <td {$celltag}>
                <img onload="cpmRunSlideInit()" src="{$cpmloadingpngurl}" {$imgtags} name="SlideShow">
            </td>
            </tr>
        </table>
        </html>
    EOT;


        // Write out HTML template for the screen depending on what we've chosen to display
        if ($showlink  &&  $showtitle) print $cpmtemplate_link_title;
        if (!$showlink &&  $showtitle) print $cpmtemplate_nolink_title;
        if ($showlink  && !$showtitle) print $cpmtemplate_link_notitle;
        if (!$showlink && !$showtitle) print $cpmtemplate_nolink_notitle;
    }
    $objCpm->cpm_close();   // Tidy up by closing the database connections      
    return($imagesFound);
}  // End function cpmslideshow


function cpmprepareslideshow($setupfilename="") {

    echo <<<EOT
    <!doctype html>
    <html>
    <!--   cpmslideshow.php  -->
    <!--   Created by KF (406man) from slideshow.php supplied with cpmfetch in previous versions  -->
    <!--   It pulls in a configuration file cpmslideshowconfig.inc.php which contains various parameters -->
    <!--   to determine the content and appearance of the slideshow.   -->
    <!--   There should be no need to change the code here as all parameters are in the configuration file -->
    <!--   cpmfetch Release 2.2 -->
    <head>
    <script>
        var slideShowTimer = 3500  // Default time in mS that the image is shown
        var slideShowOffTime = 900   // Time in mS that the image is off the screen
        var transitionduration = "0.75s"   // Time in seconds for the fade-in and fade-out
        var Pic = new Array()
        var Lnk = new Array()
        var Ttl = new Array()
        var alt = new Array()
        let preLoad = new Array()
        let a = 0
        let showlink = false
        let showtitle = false
    </script>
    EOT;

    // If images found, call the PHP function to generate the javascript which runs the slideshow. Must come before the following js script
    if (cpmslideshow($setupfilename)) {

    $js2= <<<EOT
        <script>
        var t
        var j = 0
        var p = Pic.length
        var cpmslideshowgo = true                       // Whether the slide show keeps running
        var showstarted = false
        for (i = 0; i < p; i++){
           preLoad[i] = new Image()
           preLoad[i].src = Pic[i]
        }

            function cpmprocesskey(code) {
            	switch (code) {                        // These keys only switch off
            		case 13:                           // Return
                    case 27:                           // Escape
                        cpmslideshowgo = false
            			break;
            		case 32:                           // Space toggles on / off
                        if (cpmslideshowgo == false) {  // It seems counterintuitive to restart the slideshow by calling the stop routine but that's the way to get the fade to work properly
                            cpmslideshowgo = true
                            cpmRunSlideShowOff()
                            break
                        } else {  
                            cpmslideshowgo = false
            			    break;
                        }
            		default:
            			break;
            	}
            }


            function cpmSlideKeyDowned(e) {
                cpmprocesskey(e.keyCode)
            }

            function cpmRunSlideInit() {
                if (!showstarted) {         /* As this routine is triggered every time an image is loaded, make sure it only runs once to initialise */
                    document.addEventListener("keydown", cpmSlideKeyDowned)
                    document.images.SlideShow.style.transitionProperty = "opacity"
                    document.images.SlideShow.style.transitionDuration = transitionduration
                    document.images.SlideShow.style.transitionTimingFunction = "ease"
                    cpmRunSlideShowOn()
                    showstarted = true
                }
            }

            function cpmRunSlideShowOff(){

                if (cpmslideshowgo) {
                    document.images.SlideShow.style.opacity = "0"
                    t = setTimeout('cpmRunSlideShowOn()', slideShowOffTime)
                }
            }

            function cpmRunSlideShowOn(){

                document.images.SlideShow.src = preLoad[j].src
                if (alt[j] != "") {
                    document.images.SlideShow.alt = alt[j]
                    document.images.SlideShow.title = alt[j]
                }
                document.images.SlideShow.style.opacity = "1.0"
                Lnk[j] = Lnk[j].replace(/&#039;/gi, "'")    // In the link replace the code for ' by an actual '    
                if (showlink) document.links.slidelink.href = Lnk[j]
                var x = document.getElementById('Titlefield')
                if (showtitle) {
                    document.getElementById('Titlefield').innerHTML = Ttl[j]
                } 
                j = j + 1
                if (j > (p-1)) j=0
                if (cpmslideshowgo) t = setTimeout('cpmRunSlideShowOff()', slideShowTimer)
            }
        </script>
        <style>
        .slidedisplay {
            display: inline-block;   /* inline-block ensures just the image is the clickable link */
        }
        </style>
    EOT;

    echo $js2;
}


}  // End function cpmprepareslideshow

