<?php

// testfetch.php  Test program to fetch images using CPMFETCH and display results. 
// Run this program in a web browser using, for example https://www.yourdomain.com/gallery/cpmfetch/testfetch.php
// cpmfetch release 2.2   Newly introduced by KF (406man)
//
// Must live in the main cpmfetch directory
// There should be no need to change anything in this script as all the setup parameters are in an included file named
// Option 1) cpmfetch_code.inc.php   or   Option 2) cpmfetch_codexxx.inc.php    where xxx is any text but typically a number
// If cpmfetch_code.inc.php doesn't exist, program will look for all cpmfetch_codexxx.inc.php and user will be prompted

global $_GET, $cpmfetchdir;
$cpmfetchdir = __DIR__ . "/";       // This is the cpmfetch directory which will be used later in various require statements 
$default_codefile = 'cpmfetchsetup.inc.php';
$cpmfetchmainfile = "cpmfetch.php";           // As this test program is in the main cpmfetch directory, only file name is needed here
$inc_directory = "./inc/";
$search_pattern = "cpmfetchsetup*.inc.php";     // Names of setup files to look for
if (array_key_exists('cpmtestfetchfilename', $_GET)) {  // See if setup file name was passed in
    $cpmsetupfile = $_GET['cpmtestfetchfilename'];
    $changesetupfile = <<<EOT
        <form id="cpmresetfile" action="testfetch.php" method="get">
        <button type="submit" class="button" formmethod="get" style="text-align:center" value="yes" name="change">Change Setup File</button>
        </form>
EOT;
} else {
    $cpmsetupfile = $default_codefile;     // If not, use the default setup filename
    $changesetupfile = "";
}

// Beginning of simple HTML pages ----------------------------------------------------------
$htmlpagehead = <<< EOT
    <!doctype html>
    <html>
    <head>
    <title>CPM Test Fetch Page</title>
    <meta name="CPM Test Fetch Page" content="First page">
    </head>
    <body> 
    <B>Test Program for cpmfetch</B> - testfetch.php<br>
EOT;


$htmlpage2 = <<< EOT
    </body>
    <p>End of cpmfetch test program</p>
    </html>
EOT;
// End of simple HTML pages ----------------------------------------------------------

$cpmsetupfilepath = $inc_directory . $cpmsetupfile;     // Reach down into the /inc directory for these files
if (file_exists($cpmsetupfilepath)) {  // Setup file name either passed in or default is used. If it doesn't exist, ask for it
    echo $htmlpagehead;        // Display the beginning of the simple page
    testfetchstart($cpmsetupfile, $cpmsetupfilepath, $changesetupfile);
    require($cpmfetchmainfile);                    // Pull in the main file cpmfetch.php
    $objCpm = new cpm("");                      
    require($cpmsetupfilepath);             // This contains the code to be tested 
    testfetchend($htmlpage2);
    $objCpm->cpm_close();                       
           
} else {
    $htmllinebreak = "<br>";
    $fullsearch = $inc_directory . $search_pattern;
    $before_dir = getcwd();
    $file_array = glob($fullsearch);
    $output_option = array();
    $i = 0;
    if ($file_array) {          // If the file array exists  i.e. some files were found  
        echo $htmlpagehead;        // Display the beginning of the simple page
        echo "<table width=\"70%\">";
        echo '<form id="cpgfetchfile" action="testfetch.php" method="get">';
        echo "Choose Setup File";
        foreach ($file_array as $cpmincfile) {
            $i++;
            $cpmincfile = basename($cpmincfile);            // Strip out directory leaving just the filename
            $output_option[$i] = ($i==1) ? "checked=\"checked\"" : "";  // Radio button selected always defaults to file 1
            echo <<<EOT
                <tr>
                    <td class="tableb" width="30%">
                        <label for="cpmtestfetchfilename" class="clickable_option">File {$i}: {$cpmincfile}</label>
                    </td>
                    <td class="tableb" colspan="1">
                        <input type="radio" name="cpmtestfetchfilename" id="cpmfetch_file{$i}" class="radio" value="{$cpmincfile}" {$output_option[$i]}/>
                        <label for="cpmfetch_file{$i}" class="clickable_option"></label>
                    </td>
                </tr>
EOT;
        }

        echo <<<EOT
            <tr>
                <td class="tableb" width="40%">
                </td>
                <td class="tablef" colspan="2">
                    <button type="submit" class="button" formmethod="get" style="text-align:center" name="">Submit</button>
                    </form>
                </td>
            </tr>
EOT;

        echo $htmlpage2;
        echo "</table>";
        
    } else {
        echo "No files found matching " . $search_pattern . " in directory " . getcwd() . $inc_directory . $htmllinebreak;
    }    
}
//End of main body of program
//-----------------------------
    function testfetchstart($cpmsetupfilename, $cpmsetupfile, $changesetupfile) {
        $this_file = file_get_contents($cpmsetupfile);   // Read in this file so we can extract the cpfmfetch commands and display them
        if (!$this_file) {
            echo "testfetch.php: File containing setup code to be tested was not found";
            exit;
        } else {
            $cpm_view_found = false;
            $picsfoundmsg = "If the cpmfetch commands have found some pictures they will appear below between the two lines.";
            $textfoundmsg = "If the cpmfetch commands successfully generate some text it will appear below between the two lines.";
            $pattern = "#\/\/= Start(.*?)//= End#s";
            preg_match($pattern, $this_file, $userblock);   // Extract the whole block between the markers containing the cpfmfetch commands
            if (isset($userblock)) {                // Check that the code block was found. Problem if not
                $cpmfetch_commands = '';
                $code_array = preg_split("/\r\n|\n|\r/", $userblock[0]); // Convert code block into array of strings
                foreach ($code_array as $element) {      // Run through the array of code 
                    if ($element <> "") {                 // ignore blank lines
                        $len = strlen($element);
                        $search_length = ($len < 5) ? $len : 5;   // Use length of string if less than 5 chars, or 5 chars
                        // Search the first five character in the line for the comment delimiter. If not there, build variable containing just the cpmfetch commands
                        if (substr_count($element, "//", 0, $search_length) == 0) {
                            $cpmfetch_commands .= $element . '<br>';
                            // Look for "cpm_view" to tailor the message about what should appear
                            if (strpos($element, "cpm_view") !== false) $cpm_view_found = true;
                        }  
                    }
                }
            } else {
                echo "testfetch.php: Block of setup code not found in cpmfetch_code.inc.php";
                exit;
            }
        $what_to_see_msg = $cpm_view_found ? $picsfoundmsg : $textfoundmsg;
        echo <<< EOT
            The setup file is: <code>{$cpmsetupfilename}</code>
            {$changesetupfile}
            The commands used were:<br>
            <pre>{$cpmfetch_commands}</pre>
            {$what_to_see_msg} <br>
            <hr>
        EOT;
        }
    } // End testfetchstart
//-----------------------------
    function testfetchend($endhtmlcode) {
    // Display end of page 
        echo "<hr";
        echo $endhtmlcode;
    } // End testfetchend
//-----------------------------   

?>





